package
Version:
v1.2.0
Opens a new window with list of versions in this module.
Published: Feb 18, 2026
License: MIT
Opens a new window with license information.
Imports: 3
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
Generate creates a random ID (12 characters, URL-safe)
func GenerateRoomCode() string
GenerateRoomCode creates a 6-character room code (uppercase, no confusing chars)
Source Files
¶
Click to show internal directories.
Click to hide internal directories.